@@ -1,12 +1,12 @@
 import logging
 import time
 from dataclasses import dataclass
-from typing import Type, Optional, List
+from typing import Type, List
 
 from aiohttp import BasicAuth
 from http_tools.http_server_connector import HttpServerConnector
 
-from .elements.aggregation_function import AggregationFunction
+from .elements.abstract.selectable import Selectable
 from .elements.output_format import OutputFormat
 from .statements.abstract_statement import AbstractStatement
 from .statements.count import Count
@@ -15,7 +15,7 @@ from .statements.insert import Insert
 from .utils.charset import Charset
 from .statements.select import Select
 from .elements.result import Result
-from .elements.filter_by import Filter
+from .elements.filter_by import Filter, Condition
 from .elements.order import Order
 from .elements.column import Column
 from .elements.table import Table
@@ -62,20 +62,19 @@ class ClickHouseConnector:
     async def select(self,
                      table: Type[Table],
                      *,
-                     columns: Optional[List[Column]] = None,
-                     filter_by: Optional[List[Filter]] = None,
-                     search_by: Optional[List[Filter]] = None,
-                     group_by: Optional[List[Column]] = None,
-                     order_by: Optional[List[Order]] = None,
-                     offset: Optional[int] = None,
-                     limit: Optional[int] = None,
+                     selectables: list[Selectable] | None = None,
+                     condition: Condition | None = None,
+                     group_by: List[Selectable] | None = None,
+                     order_by: List[Order] | None = None,
+                     offset: int | None = None,
+                     limit: int | None = None,
                      output_format: OutputFormat = OutputFormat.Dict,
-                     aggregation_functions: Optional[List[AggregationFunction]] = None
+                     distinct_on: List[Selectable] | None = None
                      ) -> list:
         result = await self.execute_statement(
             statement=Select(
-                table, columns, filter_by, search_by, group_by,
-                order_by, offset, limit, output_format, aggregation_functions
+                table, selectables, condition, group_by,
+                order_by, offset, limit, output_format, distinct_on
             )
         )
         return result.fetchall()
@@ -83,8 +82,8 @@ class ClickHouseConnector:
     async def count(self,
                     table: Type[Table],
                     *,
-                    filter_by: Optional[List[Filter]] = None,
-                    search_by: Optional[List[Filter]] = None,
+                    filter_by: List[Filter] | None = None,
+                    search_by: List[Filter] | None = None,
                     ) -> int:
         result = await self.execute_statement(statement=Count(table, filter_by, search_by))
         return result.fetchone()
