@@ -26,6 +26,8 @@ class Select(AbstractStatement):
     offset: int | None = None
     limit: int | None = None
     output_format: OutputFormat = OutputFormat.Dict
+    distinct_on: list[Selectable] = field(default_factory=list)
+
 
     def __post_init__(self):
         self.table.get_table_engine().preprocess_select_request(self)
@@ -37,6 +39,11 @@ class Select(AbstractStatement):
     def generate_sql(self):
         table_name = self.table.get_name()
         select_sql = ', '.join(selectable.to_selector() for selectable in self.selectables)
+        if self.distinct_on:
+            if not self.order_by:
+                raise NotImplementedError("order by required when selecting distinct_on")
+            select_sql = \
+                f"DISTINCT ON({', '.join(selectable.to_selector() for selectable in self.distinct_on)}) " + select_sql
         where_sql = f'\nWHERE {self.condition.to_sql()}' if self.condition else ''
 
         group_by_part = ', '.join((g.to_sql() for g in self.group_by))
